# PySide6 helpers

Bits of code used in most PySide6 based projects

This project is alpha: expect breaking changes

## Icons

Icons made by [Freepik](https://www.freepik.com/) and found on [Flat Icon](https://www.flaticon.com)

See [this page](icons.md) for usage and reference

## Notes

- consider using [`importlib.resources`](https://docs.python.org/3/library/importlib.resources.html) instead of `pyside6helpers.resources`

## Disclaimer

Please add this sentence to your readme/about

> This project uses [PySide6 helpers](https://github.com/MrFrangipane/pyside6-helpers) which icons were made by [Freepik](https://www.freepik.com/) and found on [Flat Icon](https://www.flaticon.com)
